@@ -19,9 +19,9 @@ try:
 except ImportError:
     MAX_GET_RESULTS = None
 
-from .conf import model_profile, redis_client, handle_connection_failure, LRU
+from .conf import model_profile, redis_client, handle_connection_failure, LRU, ALL_OPS
 from .utils import monkey_mix, get_model_name, stamp_fields, load_script, \
-                   func_cache_key, cached_view_fab
+                   func_cache_key, cached_view_fab, get_thread_id
 from .tree import dnfs
 from .invalidation import invalidate_obj, invalidate_dict
 
@@ -157,7 +157,7 @@ class QuerySetMixin(object):
     def cache(self, ops=None, timeout=None, write_only=None):
         """
         Enables caching for given ops
-            ops        - a subset of ['get', 'fetch', 'count'],
+            ops        - a subset of {'get', 'fetch', 'count', 'exists'},
                          ops caching to be turned on, all enabled by default
             timeout    - override default cache timeout
             write_only - don't try fetching from cache, still write result there
@@ -167,8 +167,8 @@ class QuerySetMixin(object):
         """
         self._require_cacheprofile()
 
-        if ops is None:
-            ops = ['get', 'fetch', 'count']
+        if ops is None or ops == 'all':
+            ops = ALL_OPS
         if isinstance(ops, str):
             ops = [ops]
         self._cacheconf['ops'] = set(ops)
@@ -307,12 +307,6 @@ class QuerySetMixin(object):
 # We need to stash old object before Model.save() to invalidate on its properties
 _old_objs = {}
 
-# This will help with thread-safe _old_objs access
-import threading
-def get_thread_id():
-    return threading.current_thread().ident
-
-
 class ManagerMixin(object):
     @once_per('cls')
     def _install_cacheops(self, cls):
