@@ -3,6 +3,7 @@ import re
 from functools import wraps
 import json
 import inspect
+import threading
 import six
 from funcy import memoize
 from .cross import md5hex
@@ -150,3 +151,9 @@ def carefully_strip_whitespace(text):
     text = re.sub(r'>\s*\n\s*<', NEWLINE_BETWEEN_TAGS, text)
     text = re.sub(r'>\s{2,}<', SPACE_BETWEEN_TAGS, text)
     return text
+
+
+# This will help mimic thread globals via dicts
+
+def get_thread_id():
+    return threading.current_thread().ident
